# Scripts to generate publication-ready figures about sequential road networks

This repository contains Python scripts and auxiliary data to reproduce the figures of an [article](https://doi.org/10.1093/pnasnexus/pgac313) that introduces *sequential road networks*. Its purpose is to make our research transparent and reproducible with little effort.

## Dependencies

The scripts require **Python 3** and the following packages:

- `kaleido`
- `more_itertools`
- `networkx`
- `numpy`
- `picos`
- `plotly`
- `scipy`
- `shapely`
- `similaritymeasures`

## Preparations

It is necessary to clone this repository together with its submodules (ef5-6/srn-toolbox> and ef5-6/srn-dashboard>):

```
git clone --recurse-submodules https://gitlab.com/EF5-6/srn-figures.git
```

If you have already cloned the repository but not its submodules, you can also pull them with the command:

```
git submodule update --init
```

## Usage

A [Makefile](Makefile) is included to facilitate use of the scripts. It is highly recommended to first execute:

```
make precomputed
```

This will copy the data from the [precomputed_data](precomputed_data) subfolder into the main folder. If the command above is skipped, then this data will be generated by `make`, which is computationally expensive and may take a few hours depending on your platform.

Finally, you can execute:

```
make
```

This will first verify that the necessary Python modules are present and then produce publication-ready figures in PDF format.

Some figures require a more complex data management and are excluded from the above workflow. They can be generated with:

```
make extra
```

Note that no precomputed data is available for these figures and that producing it may require additional dependencies.

## Source layout

Apart from the Python scripts and the Makefile, this repository contains two data folders:

- [precomputed_data](precomputed_data) contains data that can be reprodced by the scripts,
- [external_data](external_data) contains data that was pre-computed by the authors and is not generated by the scripts.

## License

The source code is licensed under the [GNU GPL v3](LICENSE.txt).

The data in the [precomputed_data](precomputed_data) and [external_data](external_data) subfolders is made available under the [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.

## Citing

The generated figures appeared in the following [article](https://doi.org/10.1093/pnasnexus/pgac313).

```bibtex
@article{SSDK23,
  author  = {Maximilian J. Stahlberg and Guillaume Sagnol and Benjamin Ducke and Max Klimm},
  title   = {Spatiotemporal reconstruction of ancient road networks through sequential cost--benefit analysis},
  journal = {PNAS Nexus},
  volume  = {2},
  number  = {2},
  pages   = {1--10},
  year    = {2023},
  doi     = {10.1093/pnasnexus/pgac313}
}
```
